venn <- function(id, category, cutoff=1, duplicates = FALSE, tab, main) {
    
    if (missing(tab)) {
	
	# Create incidence table from id and category
	
	tab <- incidence.table(as.character(id), category, cutoff=cutoff, 
			       duplicates = duplicates)
			       
	if (missing(main)) main <- paste("Count of", deparse(substitute(id)), 
	 				 "by", deparse(substitute(category)))
    } else if (missing(main)) 
    	main <- paste("Venn diagram of", deparse(substitute(tab)))
    
    # Convert rows to binary numbers and count them
    
    index <- tab %*% 2^(1:ncol(tab) - 1)
    itab <- table(index)
    
    save <- par(pty="s",	# Must be square to get labels right 
    		mar=c(1, 0, 1, 0)*par("mar")) # Don"t need side margins

    on.exit(par(save))
    
    if (ncol(tab) == 2) {
	
	# Set up coordinates.  xlim and ylim must be same length or coordinate
	# system will not be isometric
	
	plot(1, 1, xlim=c(-1.3, 2.3), ylim=c(-1.8, 1.8), bty="n", axes=FALSE, 
	     type="n", xlab="", ylab="", main=main)
	     
	if (!is.na(zero <- itab[as.character(0)])) 
	    title(sub=paste(zero, "not shown"))
	
	# Plot 2 circles
	
	cx <- c(0, 1.1)
	cy <- c(0, 0)
	mx <- mean(cx)
	my <- mean(cy)
	symbols(cx, cy, circles=rep(1, 2), inches=FALSE, add=TRUE)
	
	# Put counts in the regions
	
	text(c(mx + 2*(cx[1] - mx), mx + 2*(cx[2] - mx)),
		 c(my + 2*(cy[1] - my), my + 2*(cy[2] - my)),
		 itab[as.character(c(1, 2))])
	text(mx, my, itab["3"])
	
	# Label the circles
	
	# text(c(cx[1] -1, cx[2] + 1), c(0, 0),	     
	#     pos=c(2, 4), colnames(tab))	
	
	text(c((mx + 3*(cx[1] - mx) + cx[1])/2,      (mx + 3*(cx[2] - mx) + cx[2])/2),
	     c((my + 3*(cy[1] - my) + cy[1] -1.8)/2, (my + 3*(cy[2] - my) + cy[2] -1.8)/2),
	     pos = c(2, 4), colnames(tab))	     
	
		 
     } else if (ncol(tab) == 3) {
	 
	# Set up coordinates.  xlim and ylim must be same length or coordinate
	# system will not be isometric
	
	plot(1, 1, xlim=c(-1.5, 2.6), ylim=c(-1.5, 2.6), bty="n", axes=FALSE, 
	     type="n", xlab="", ylab="", main=main)
	     
	if (!is.na(zero <- itab[as.character(0)])) 
	    mtext(paste(zero, "not shown"), side=1)
	
	# Plot 3 circles
	
	cx <- c(0, 1.1, 0.55)
	cy <- c(0, 0, 1.1*sqrt(3)/2)
	mx <- mean(cx)
	my <- mean(cy)
	symbols(cx, cy, circles=rep(1, 3), inches=FALSE, add=TRUE)
	
	# Put counts in the regions
	
	text(c(mx + 2*(cx[3] - mx), mx + 2*(cx[1] - mx), mx + 2*(cx[2] - mx)),
	     c(my + 2*(cy[3] - my), my + 2*(cy[1] - my), my + 2*(cy[2] - my)),
	     itab[as.character(c(1, 2, 4, ))])
	text(c(mx + (cx[1] + cx[3] -2*mx), mx + (cx[2] + cx[3] -2*mx), 	
	       mx + (cx[2] + cx[1] -2*mx)),
	     c(my + (cy[1] + cy[3] -2*my), my + (cy[2] + cy[3] -2*my), 	
	       my + (cy[2] + cy[1] -2*my)),
	     itab[as.character(c(3, 5, 6, ))])     
	text(mx, my, itab["7"])
	
	# Label the circles
	
	text(c(mx + 2.6*(cx[3] - mx), (mx + 3*(cx[1] - mx) + cx[1])/2,      
	       (mx + 3*(cx[2] - mx) + cx[2])/2),
	     c(my + 2.6*(cy[3] - my), (my + 3*(cy[1] - my) + cy[1] - 1.2)/2, 
	       (my + 3*(cy[2] - my) + cy[2] - 1.2)/2),
	     pos = c(3, 2, 4), colnames(tab))	     
    } else stop("Can only Venn 2 or 3 categories")
}

incidence.table <- function(id, category, names = NULL, cutoff = 1, 
			    duplicates = FALSE) {
    if (!duplicates) {
	
	# Count combinations and convert to TRUE/FALSE
	
    	tab <- table(as.character(id), category)
    	tab >= cutoff
    	
    } else {
	
	# Count combinations
	
    	tab <- table(as.character(id), category)
    	
    	# Set up matrix with one row per id
    	
	result <- matrix(FALSE, length(id), ncol(tab))
	
	# Set appropriate entries TRUE
    	
    	for (i in 1:ncol(tab)) 
    	    result[, i] <- tab[as.character(id), i] >= cutoff
    	
    	# Return nice looking matrix
    	
    	rownames(result) <- as.character(names)
    	colnames(result) <- colnames(tab)
    	result
    }
}