\name{incidence.table}
\alias{incidence.table}
\title{ Produce incidence table }
\description{
Given a list of (ID, Category) pairs, produces a table
of all categories into which each ID falls.
}
\usage{
incidence.table(id, category, names = NULL, cutoff = 1, duplicates = FALSE)
}
\arguments{
  \item{id}{ The ID of an individual }
  \item{category}{ The category into which that individual falls }
  \item{names}{ Optional names for each record }
  \item{cutoff}{ The number of cases of (id, category) required }
  \item{duplicates}{ Should duplicate (id, category) values be collapsed? }
}
\value{
If duplicates is \code{FALSE} (the default), returns a logical matrix with a row 
for every unique \code{id}, and a column for every
unique \code{category}.  An entry is \code{TRUE} if at least \code{cutoff} (default 1) 
such pairs occur in the data.

If duplicates is \code{TRUE}, then the rows of the matrix will correspond to 
the original records in the data, optionally named using the \code{names} parameter.
Entries will be \code{TRUE} if at least  \code{cutoff} \code{(id, category)} pairs
occur in the data.
}
\author{ Duncan Murdoch }
\seealso{ \code{\link{venn}}}

\examples{
    dat <- data.frame(id=c(1,1,1,2,2,3,4,5,6),
                      cat=rep(c('Red','Green','Blue'),3),
                      name=letters[1:9])
    dat
    incidence.table(dat$id,dat$cat)
    incidence.table(dat$id,dat$cat,dat$name,duplicates=TRUE)
}
\keyword{category}
