\name{venn}
\alias{venn}
\title{ Draw Venn diagram }
\description{
Draws a Venn diagram for a list of items, with possible repeated entries.
}
\usage{
venn(id, category, cutoff = 1, duplicates = FALSE, tab, main)
}
\arguments{
  \item{id}{ The IDs defining the individual corresponding to each record (see below) }
  \item{category}{ The IDs defining which category each record falls in (see below) }
  \item{cutoff}{ The minimum number of duplicate records required to count (default 1) }
  \item{duplicates}{ If TRUE, count individuals rather than \code{id}s }
  \item{tab}{ Incidence table to graph (see below) }
  \item{main}{ Title for the plot (optional) }
}
\details{
 Venn diagrams are used in elementary set theory to illustrate the concepts of
 intersections and unions of sets.  This function augments these diagrams to display
 counts in multiple categories and their intersections.  Although Venn
 diagrams of more than 3 sets are possible, in general they can't be drawn with circles,
 and this function does not support them.
 
 The function assumes that a categorization of some individuals has been recorded by 
 listing the individual ID together with each category it falls into.  For example, the 
 individuals might be measurements on individual protein samples, the \code{id} might be an
 identifier of the protein in that sample, and the category might be the tissue 
 library where each was seen, in a large number of samples from several libraries.  
 The function will show how many proteins fall in each library. 
 Multiple samples of the same \code{(id, category)} pair will only be counted once
 unless \code{duplicates = TRUE} is specified.
 
 The function works in two modes.  If \code{tab} is given, it should be a 2 or
 3 column logical matrix, indicating the incidence of each row in categories given
 by each column, e.g. the output of \code{\link{incidence.table}}.  
 
 If \code{tab} is missing, \code{\link{incidence.table}} is called to produce the 
 table.
  
 If \code{cutoff > 1}, then only cases with at least \code{cutoff} multiple entries (i.e. 
 \code{id} and \code{category} matching exactly in at least \code{cutoff} records) will be used
 in the diagram.
}
\value{
 This function is used to draw the plot; no useful value is returned.
}
\author{ Duncan Murdoch }
\references{ For general information on Venn diagrams, 
see \url{http://www.combinatorics.org/Surveys/ds5/VennWhatEJC.html}.}
\seealso{ \code{\link{incidence.table}}}
\examples{
  dat <- data.frame(id=c(1,1,1,1,1,1,2,2,3,4,5,6),
  			        cat=rep(c('Red','Green','Blue'),4),
  			        name=letters[1:12])
  dat
  venn(dat$id,dat$cat)
  venn(dat$id,dat$cat,cutoff = 2)
}
\keyword{ hplot }
